# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

### Added

* Added `compas_gmsh.models.Model.options.mesh.algorithm`.
* Added `compas_gmsh.models.Model.options.mesh.lmin`.
* Added `compas_gmsh.models.Model.options.mesh.lmax`.
* Added `compas_gmsh.models.Model.options.mesh.mesh_only_empty`.
* Added `compas_gmsh.models.Model.options.mesh.meshsize_extend_from_boundary`.
* Added `compas_gmsh.models.Model.options.mesh.meshsize_min`.
* Added `compas_gmsh.models.Model.options.mesh.meshsize_max`.
* Added `compas_gmsh.models.Model.options.mesh.meshsize_from_curvature`.
* Added `compas_gmsh.models.Model.options.mesh.meshsize_from_points`.
* Added `compas_gmsh.models.Model.options.mesh.min_nodes_circle`.
* Added `compas_gmsh.models.Model.options.mesh.min_nodes_curve`.

### Changed

### Removed

* Removed `compas_gmsh.models.Model.mesh_lmin`.
* Removed `compas_gmsh.models.Model.mesh_lmax`.

